@@ -50,6 +50,7 @@ REFRESH_DATA = parse_bool_env("TEXTA_MLP_REFRESH_DATA", False)
 SUPPORTED_ANALYZERS = (
     "lemmas",
     "pos_tags",
+    "word_features",
     "transliteration",
     "ner",
     "addresses",
@@ -63,6 +64,7 @@ SUPPORTED_ANALYZERS = (
 DEFAULT_ANALYZERS = [
     "lemmas",
     "pos_tags",
+    "word_features",
     "transliteration",
     "ner",
     "addresses",
@@ -268,44 +270,22 @@ class MLP:
     def get_stanza_pipeline(self, lang: str):
         if lang not in self._stanza_pipelines:
             if lang in self.custom_ner_model_langs:
-                try:
-                    self._stanza_pipelines[lang] = stanza.Pipeline(
-                        lang=lang,
-                        dir=str(self.stanza_resource_path),
-                        processors=self._get_stanza_processors(lang),
-                        ner_model_path=f"{self.custom_ner_model_Path}/{lang}",
-                        use_gpu=self.use_gpu,
-                        logging_level=self.logging_level,
-                    )
-                # This is for CUDA OOM exceptions. Fall back to CPU if needed.
-                except RuntimeError:
-                    self._stanza_pipelines[lang] = stanza.Pipeline(
-                        lang=lang,
-                        dir=str(self.stanza_resource_path),
-                        processors=self._get_stanza_processors(lang),
-                        ner_model_path=f"{self.custom_ner_model_Path}/{lang}",
-                        use_gpu=False,
-                        logging_level=self.logging_level,
-                    )
+                self._stanza_pipelines[lang] = stanza.Pipeline(
+                    lang=lang,
+                    dir=str(self.stanza_resource_path),
+                    processors=self._get_stanza_processors(lang),
+                    ner_model_path=f"{self.custom_ner_model_Path}/{lang}",
+                    use_gpu=self.use_gpu,
+                    logging_level=self.logging_level,
+                )
             else:
-                try:
-                    self._stanza_pipelines[lang] = stanza.Pipeline(
-                        lang=lang,
-                        dir=str(self.stanza_resource_path),
-                        processors=self._get_stanza_processors(lang),
-                        use_gpu=self.use_gpu,
-                        logging_level=self.logging_level,
-                    )
-                # This is for CUDA OOM exceptions. Fall back to CPU if needed.
-                except RuntimeError:
-                    self._stanza_pipelines[lang] = stanza.Pipeline(
-                        lang=lang,
-                        dir=str(self.stanza_resource_path),
-                        processors=self._get_stanza_processors(lang),
-                        use_gpu=False,
-                        logging_level=self.logging_level,
-                    )
-
+                self._stanza_pipelines[lang] = stanza.Pipeline(
+                    lang=lang,
+                    dir=str(self.stanza_resource_path),
+                    processors=self._get_stanza_processors(lang),
+                    use_gpu=self.use_gpu,
+                    logging_level=self.logging_level,
+                )
         return self._stanza_pipelines[lang]
 
 
